==> wcslib-contrib_4.23.orig.tar.bz2: wcslib-4.23/Fortran/spc_data.f <==
*=======================================================================
*
* WCSLIB 4.23 - an implementation of the FITS WCS standard.
* Copyright (C) 1995-2014, Mark Calabretta
*
* This file is part of WCSLIB.
*
* WCSLIB is free software: you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as published
* by the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* WCSLIB is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
* License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with WCSLIB.  If not, see http://www.gnu.org/licenses.
*
* Direct correspondence concerning WCSLIB to mark@calabretta.id.au
*
* Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
* http://www.atnf.csiro.au/people/Mark.Calabretta
* $Id: spc_data.f,v 4.23 2014/05/13 05:50:52 mcalabre Exp $
*=======================================================================

      BLOCK DATA SPC_BLOCK_DATA

      CHARACTER SPC_ERRMSG(0:4)*80

      COMMON /SPC_DATA/ SPC_ERRMSG

      DATA SPC_ERRMSG /
     :  'Success',
     :  'Null spcprm pointer passed',
     :  'Invalid spectral parameters',
     :  'One or more of x coordinates were invalid',
     :  'One or more of the spec coordinates were invalid'/

      END

==> wcslib-contrib_5.14.orig.tar.bz2: wcslib-5.14/Fortran/spc_data.f <==
*=======================================================================
*
* WCSLIB 5.14 - an implementation of the FITS WCS standard.
* Copyright (C) 1995-2016, Mark Calabretta
*
* This file is part of WCSLIB.
*
* WCSLIB is free software: you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as published
* by the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* WCSLIB is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
* License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with WCSLIB.  If not, see http://www.gnu.org/licenses.
*
* Direct correspondence concerning WCSLIB to mark@calabretta.id.au
*
* Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
* http://www.atnf.csiro.au/people/Mark.Calabretta
* $Id: spc_data.f,v 5.14 2016/02/07 10:49:32 mcalabre Exp $
*=======================================================================

      BLOCK DATA SPC_BLOCK_DATA

      CHARACTER SPC_ERRMSG(-1:4)*80

      COMMON /SPC_DATA/ SPC_ERRMSG

      DATA SPC_ERRMSG /
     :  'No change (not an error)',
     :  'Success',
     :  'Null spcprm pointer passed',
     :  'Invalid spectral parameters',
     :  'One or more of x coordinates were invalid',
     :  'One or more of the spec coordinates were invalid'/

      END
